@@ -8,7 +8,7 @@ from optparse import OptionParser
 import os
 from shutil import move
 from uuid import uuid4
-from distutils.sysconfig import get_python_lib
+from utils import path_for_import
 
 def create_project():
     """
@@ -55,8 +55,8 @@ def create_project():
     # each of the packages. An alternate package will overwrite
     # files from Mezzanine.
     for package_name in packages:
-        package_path =get_python_lib()
-        copy_tree(os.path.join(package_path+"/"+package_name, "osiot"), project_path)
+        package_path = path_for_import(package_name)
+        copy_tree(os.path.join(package_path, "../osiot"), project_path)
 
     # Clean up pyc files.
     for (root, dirs, files) in os.walk(project_path, False):
